;+
;
; .. _tropflux_init.pro:
;
; =================
; tropflux_init.pro
; =================
;
; DESCRIPTION
; ===========
;
; This is the SAXO initialisation file.
; it defines the !path and the defaut values of some of the common variables
;
;
; It ++::
;
;   $ idl -startupfile tropflux_init.pro
;
; or::
;   $ idl -IDL_STARTUP tropflux_init.pro
;
; or::
;
;  $ IDL
;  IDL> @tropflux_init
;
;
; SEE ALSO
; ========
;
; :ref:`tropflux_profile.sh`
;
; TODO
; ====
;
; learn to write IF .. ELSE in a @file
;
; check idl -IDL_STARTUP tropflux_init.pro not ok now on cratos
;
; EVOLUTIONS
; ==========
;
; - fplod 20110411T074056Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * remove fplod/cratos dependencies use $TROPFLUX*; use SAXO_SRC;
;     add cm_tropflux
;
; - fplod 20110408T131625Z cratos.locean-ipsl.upmc.fr (Linux)
;
;   * creation using buildinit on cratos
;
;-
; 
; SAXO environment
saxo_src_env=GETENV('SAXO_SRC')
; tropflux environment
@cm_tropflux
tropflux_env=GETENV('TROPFLUX')
tropflux_id_env=GETENV('TROPFLUX_ID')
tropflux_od_env=GETENV('TROPFLUX_OD')

; path definition
;
!path = expand_path('+' + tropflux_env + '/src') $
      + path_sep(/search_path) + expand_path('+' + saxo_src_env) $
      + path_sep(/search_path) + expand_path('+' + !dir)
;
; compatibility with the old version
;
keep_compatibility, 0
;
; define all the commons
;
@cm_4cal
@cm_4data
@cm_4mesh
@cm_4data
;
; define default directories
;
homedir = isadirectory(tropflux_env + '/src/', title = 'Select the default HOME directory')
iodir = isadirectory(tropflux_id_env, title = 'Select the default IO directory')
psdir = isadirectory(tropflux_od_env, title = 'Select the default postscripts directory')
imagedir = isadirectory(tropflux_od_env, title = 'Select the default images directory')
animdir = isadirectory(tropflux_od_env, title = 'Select the default animations directory')
;
; define printer parameters
;
printer_human_names = ''
printer_machine_names = ''
print_command = ''
;
; colors ...
;
device, decomposed = 0
device, retain = 2
lct, 39
;
; postscript parameters ...
;
key_portrait = 0
page_size = [20.9903, 29.7039]
windowsize_scale = 1.00000
archive_ps = 0
;
;========================================================
; end of the part that should be modified by the users...
;========================================================
;
; if needed, keep compatibility with the old version
;
@updateold
;
